## R scripts for conducting the simulations described in the main text, 
## and the computations comparing the joint probabilities of two random events
## versus the product of marginal probabilities.


## PROCEDURE 1

N<-5 # This set N=5. [Substitute by other value to simulate any other N]

results.g1<-matrix(ncol=4, nrow=10000) # Matrix to save the results
colnames(results.g1)<-c("gamma", "alpha", "betamult", "betaadd")

gamma.dist<-as.vector(10:1000) # Distribution of gamma

# Take 10000 pairs of gamma and alpha
for (i in 1:10000){
gamma<-sample(gamma.dist, 1) # Select a random value of gamma 
alpha.dist<-seq((gamma/N),gamma, by=0.1) # Distribution of alpha consistent with gamma and N
alpha<-sample(alpha.dist, 1) # Select a random value of alpha
beta.mult<-gamma/alpha # Compute multiplicative beta
beta.add<-gamma-alpha # Compute additive beta
results.g1[i,1]<-gamma
results.g1[i,2]<-alpha
results.g1[i,3]<-beta.mult
results.g1[i,4]<-beta.add
}
results.g1<-data.frame(results.g1)


# Plots of pair-wise relationships between alpha, beta and gamma

plot(alpha~gamma, pch=20, data=results.g1, xlab="Gamma", ylab="Alpha", cex.lab=1.5)

plot(betamult~alpha, pch=20, data=results.g1, xlab="Alpha", ylab="Multiplicative beta", cex.lab=1.5)

plot(betamult~gamma, pch=20, data=results.g1, xlab="Gamma", ylab="Multiplicative beta", cex.lab=1.5)

plot(betaadd~alpha, pch=20, data=results.g1, xlab="Alpha", ylab="Additive beta", cex.lab=1.5)

plot(betaadd~gamma, pch=20, data=results.g1, xlab="Gamma", ylab="Additive beta", cex.lab=1.5)


# Product of marginal probabilities vs joint probabilities

p.dist<-seq(0.1,0.9, by=0.1) # Distribution of p between 0.1 and 0.9
probs.g1<-matrix(ncol=7, nrow=100) # Matrix to save results
colnames(probs.g1)<-c("p(gamma)", "p(beta)", "prod.marginal.p", "joint.p.mult", "diff.mult", "joint.p.add", "diff.add")


# Take 100 pairs of random events
for (i in 1:100){

# p of gamma<random quantile and the respective quantile
pG<-sample(p.dist, 1)
qG<-quantile(results.g1[,1],probs=pG, names=F)

# p of multiplicative beta<random quantile and the respective quantile
pBm<-sample(p.dist, 1)
qBm<-quantile(results.g1[,3],probs=pBm, names=F)

# p of additive beta<random quantile and the respective quantile
pBa<-pBm
qBa<-quantile(results.g1[,4],probs=pBa, names=F)

# Joint probabilities
pGBm<-0
for (j in 1:nrow(results.g1)){
	pGBm<-pGBm+ifelse(results.g1[j,1]<qG&&results.g1[j,3]<qBm,1,0)
	}
pGBm<-pGBm/nrow(results.g1) # Joint p for multiplicative beta

pGBa<-0
for (j in 1:nrow(results.g1)){
	pGBa<-pGBa+ifelse(results.g1[j,1]<qG&&results.g1[j,4]<qBa,1,0)
	}
pGBa<-pGBa/nrow(results.g1) # Joint p for additive beta

probs.g1[i,1]<-pG
probs.g1[i,2]<-pBm
probs.g1[i,3]<-pBm*pG
probs.g1[i,4]<-pGBm
probs.g1[i,5]<-pGBm-(pG*pBm)
probs.g1[i,6]<-pGBa
probs.g1[i,7]<-pGBa-(pG*pBa)
}
probs.g1<-data.frame(probs.g1)


# Plot of joint p vs the product of marginal p

plot(joint.p.mult~prod.marginal.p, pch=16, cex=2, data=probs.g1, main="Procedure 1",xlim=c(0,0.9), ylim=c(0,0.9), xlab="Product of marginal p", ylab="Joint p", cex.lab=1.5)
abline(0,1)
par(new=T)
plot(joint.p.add~prod.marginal.p, pch=1, cex=2, data=probs.g1, xlim=c(0,0.9), ylim=c(0,0.9), xlab=" Product of marginal p ", ylab="Joint p", cex.lab=1.5)

# Error histograms

hist(probs.g1[,7], breaks=5, col="gray", xlab="Diff. between joint p and product of marginal p",main="", xlim=c(-0.05,0.15), ylim=c(0,25))
hist(probs.g1[,5], breaks=5, col="black", xlim=c(-0.05,0.15), ylim=c(0,25),add=T)



## PROCEDURE 2


N<-5 # This set N=5. [Substitute by other value to simulate any other N]

results.a1<-matrix(ncol=4, nrow=10000) # Matrix to save the results
colnames(results.a1)<-c("gamma", "alpha", "betamult", "betaadd")

alpha.dist<- seq(1,100, by=0.1) # Distribution of alpha


# Take 10000 pairs of alpha and gamma
for (i in 1:10000){
alpha<-sample(alpha.dist, 1) # Select a random value of alpha
gamma.dist<-seq(ceiling(alpha),(alpha*N), by=1) # Distribution of gamma consistent with alpha and N
gamma<-sample(gamma.dist, 1) # Select a random value of gamma
beta.mult<-gamma/alpha # Compute multiplicative beta
beta.add<-gamma-alpha # Compute additive beta
results.a1[i,1]<-gamma
results.a1[i,2]<-alpha
results.a1[i,3]<-beta.mult
results.a1[i,4]<-beta.add
}
results.a1<-data.frame(results.a1)

# Plots of pair-wise relationships between alpha, beta and gamma

plot(alpha~gamma, pch=20, data=results.a1, xlab="Gamma", ylab="Alpha", cex.lab=1.5)

plot(betamult~alpha, pch=20, data=results.a1, xlab="Alpha", ylab="Multiplicative beta", cex.lab=1.5)

plot(betamult~gamma, pch=20, data=results.a1, xlab="Gamma", ylab="Multiplicative beta", cex.lab=1.5)

plot(betaadd~alpha, pch=20, data=results.a1, xlab="Alpha", ylab="Additive beta", cex.lab=1.5)

plot(betaadd~gamma, pch=20, data=results.a1, xlab="Gamma", ylab="Additive beta", cex.lab=1.5)


# Product of marginal probabilities vs joint probabilities

p.dist<-seq(0.1,0.9, by=0.1) # Distribution of p between 0.1 and 0.9
probs.a1<-matrix(ncol=7, nrow=100) # Matrix to save results
colnames(probs.a1)<-c("p(alpha)", "p(beta)", "prod.marginal.p", "joint.p.mult", "diff.mult", "joint.p.add", "diff.add")

# Take 100 pairs of random events
for (i in 1:100){

# p of alpha<random quantile and the respective quantile
pA<-sample(p.dist, 1)
qA<-quantile(results.a1[,2],probs=pA, names=F)

# p of multiplicative beta<random quantile and the respective quantile
pBm<-sample(p.dist, 1)
qBm<-quantile(results.a1[,3],probs=pBm, names=F)

# p of additive beta<random quantile and the respective quantile
pBa<-pBm
qBa<-quantile(results.a1[,4],probs=pBa, names=F)

# Joint probabilities
pABm<-0
for (j in 1:nrow(results.a1)){
	pABm<-pABm+ifelse(results.a1[j,2]<qA&&results.a1[j,3]<qBm,1,0)
	}
pABm<-pABm/nrow(results.a1) # Joint p for multiplicative beta

pABa<-0
for (j in 1:nrow(results.a1)){
	pABa<-pABa+ifelse(results.a1[j,2]<qA&&results.a1[j,4]<qBa,1,0)
	}
pABa<-pABa/nrow(results.a1) # Joint p for additive beta

probs.a1[i,1]<-pA
probs.a1[i,2]<-pBm
probs.a1[i,3]<-pBm*pA
probs.a1[i,4]<-pABm
probs.a1[i,5]<-pABm-(pA*pBm)
probs.a1[i,6]<-pABa
probs.a1[i,7]<-pABa-(pA*pBa)
}
probs.a1<-data.frame(probs.a1)


# Plot of joint p vs the product of marginal p

plot(joint.p.mult~prod.marginal.p, pch=16, cex=2, data=probs.a1, main="Procedure 2",xlim=c(0,0.9), ylim=c(0,0.9), xlab="Product of marginal p", ylab="Joint p", cex.lab=1.5)
abline(0,1)
par(new=T)
plot(joint.p.add~prod.marginal.p, pch=1, cex=2, data=probs.a1, xlim=c(0,0.9), ylim=c(0,0.9), xlab="Product of marginal p", ylab="Joint p", cex.lab=1.5)


# Error histograms

hist(probs.a1[,7], breaks=5, col="gray", xlab="Diff. between joint p and product of marginal p",main="", xlim=c(-0.05,0.15), ylim=c(0,25))
hist(probs.a1[,5], breaks=5, col="black", xlim=c(-0.05,0.15), ylim=c(0,25), add=T)
